package com.ruoyi.model.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.AppBondConfig;
import com.ruoyi.model.service.IAppBondConfigService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 保证金配置Controller
 * 
 * @author ruoyi
 * @date 2025-03-08
 */
@RestController
@RequestMapping("/model/AppBondConfig")
public class AppBondConfigController extends BaseController
{
    @Autowired
    private IAppBondConfigService appBondConfigService;

    /**
     * 查询保证金配置列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppBondConfig:list')")
    @GetMapping("/list")
    public TableDataInfo list(AppBondConfig appBondConfig)
    {
        startPage();
        List<AppBondConfig> list = appBondConfigService.selectAppBondConfigList(appBondConfig);
        return getDataTable(list);
    }

    /**
     * 导出保证金配置列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppBondConfig:export')")
    @Log(title = "保证金配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppBondConfig appBondConfig) throws IOException {
        List<AppBondConfig> list = appBondConfigService.selectAppBondConfigList(appBondConfig);
        ExcelUtil<AppBondConfig> util = new ExcelUtil<AppBondConfig>(AppBondConfig.class);
        util.exportExcel(response, list, "保证金配置数据");
    }

    /**
     * 获取保证金配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppBondConfig:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(appBondConfigService.selectAppBondConfigById(id));
    }

    /**
     * 新增保证金配置
     */
    @PreAuthorize("@ss.hasPermi('model:AppBondConfig:add')")
    @Log(title = "保证金配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppBondConfig appBondConfig)
    {
        return toAjax(appBondConfigService.insertAppBondConfig(appBondConfig));
    }

    /**
     * 修改保证金配置
     */
    @PreAuthorize("@ss.hasPermi('model:AppBondConfig:edit')")
    @Log(title = "保证金配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppBondConfig appBondConfig)
    {
        return toAjax(appBondConfigService.updateAppBondConfig(appBondConfig));
    }

    /**
     * 删除保证金配置
     */
    @PreAuthorize("@ss.hasPermi('model:AppBondConfig:remove')")
    @Log(title = "保证金配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(appBondConfigService.deleteAppBondConfigByIds(ids));
    }
}
